Московский Комсомолец: происшествия, общество, культура, мнения, интервью МК
Description: Московский Комсомолец: происшествия, общество, культура, мнения, интервью
Keywords: Московский Комсомолец: происшествия, общество, культура, мнения, интервью

Логин: |
Пароль: |
Запомнить: |
| Регистрация

# mk.ru : Московский комсомолец | 24 ноября среда московское время 17:10 | Рынки:
USD | 31,2929
EUR | 41,9168
Нефть Brent | 83.67
| Погода:
сегодня |  | +1...+2
ночью |  | +1
завтра |  | +2

- Рейтинги
- Авторы
- Интервью
- Фото
- Видео
- Пресс-центр
- Опросы
- Гороскоп
- Карикатуры А.Меринова

## Главное

- ### Как начиналась война в Корее, продолжающаяся до сих пор

  #### Эксперт по Корее Константин Асмолов: «В умах нескольких поколений, переживших войну, осталась психологическая установка на противостояние».

  Крупнейший за последние полвека военный инцидент между КНДР и Республикой Корея, напомнил, что война на Корейском полуострове до сих пор не закончена. Перемирие подписанное в 1953 году, остановило вооруженную борьбу только фактически...

  Борис Золотарев Фото 8

- ### Ткачев: Банды, как в Кущевской, есть во всех регионах края

  #### Губернатор Краснодарского края разоткровенничался на заксобрании

  Александр Ткачев рассказал чиновникам о том, что банды, подобные Кущевской, существуют в каждом муниципалитете края, при этом он обещал исправить ситуацию. Также он пролил свет на мотив громкого убийства - месть за гибель брата Цапка.

  13

- ### Новозеландские шахтеры погибли после повторного взрыва

  #### Просидевшие пять дней под завалами горняки погибли после второго взрыва в шахте

  С 19 ноября спасатели Новой Зеландии разбирали завалы на шахте «Пайк ривер» после прогремевшего там взрыва. Шахтеры ждали помощи пять дней. В среду в забое прогремел еще один взрыв, не оставив шансов на спасение 29 горнякам.

  2

- ### Фига чемпионов

  #### Московский "Спартак" в очередной раз не оправдал надежд болельщиков

  Надоело! Наверное, именно это слово характеризует душевное состояние болельщиков московского «Спартака» после провального матча с марсельским «Олимпиком» в «Лужниках». Эту важнейшую встречу сезона команда Валерия Карпина проиграла со счетом 0:3.

  Кирилл Степунин 7

- ### “Сколково” — трубопровод для утечки мозгов

  #### Через инноград наладят поставку на Запад русских ученых вместе с их открытиями

  Государственная пропаганда нового экономического курса, основой которого должны стать инновации, становится все более наступательной и всепроникающей.

  Георгий Крымов Фото 53

СВОБОДНАЯ ТЕМА Никита Кричевский, экономист: Обеспеченная старость никому не обеспечена

- 24 ноября в истории
- Письма президенту

## Новости

- 17:01«Нафтогаз» продал облигации, чтобы расплатиться с «Газпромом»
- 16:48 Депутат Егиазарян объявлен в федеральный розыск
- 16:36 Смоленский таможенник поленился проверить груз с контрафактом на 2,5 млн рублей
- 16:24 Модные сети Wi-Fi вредны для деревьев
- 16:24 Среда в РГГУ очередной раз началась с эвакуации
- 16:12 Белорусская милиция задержала доверенное лицо кандидата в президенты
- 16:00 Косачев: Саакашвили можно рукоплескать, но разговаривать с ним бесполезно

Все новости

## Политика

### Якеменко хотят доставить в суд

“Якеменко под суд!” — под таким лозунгом в минувший вторник прошла акция молодежного крыла партии “Яблоко” у здания Росмолодежи в Газетном переулке.

Елена Рудская 15

| ### США и Южная Корея объединяются против КНДР? Страны-союзники запланировали совместные военные учения ФотоВидео 7 |  | ### КНДР отстреливается из тупика Ректор Дипакадемии Александр Панов — “МК”: “Войны двух Корей не будет” Михаил Ростовский 5
| ### Доведет ли Ёнпхендо до войны? Эксперт проанализировал для “МК” конфликт двух Корей Андрей Яшлавский ФотоВидео 4 |  | ### Военным в Москве жилья нет Минобороны перед выбором, что выполнять: закон или поручение президента Дмитрий Попов 18

## Видео

1:40
Тимур Родригес запел... на английском языке
1:27
Ракеты КНДР рвутся на улицах Южной Кореи
0:57
Давка в Камбодже унесла жизни 350 человек
4:50
Блогер Навальный продолжил тему "Транснефти" с помощью видео

## Партнеры

## Происшествия

### Жители Кущевской — главе СКП: “При краевых властях и ментах вам ничего не расскажут”

Встреча главы Следственного комитета при Прокуратуре РФ Александра Бастрыкина с жителями станицы Кущевской Краснодарского края, где 4 ноября произошло жестокое убийство 12 человек, не принесла весомых результатов.

Светлана Самоделова 53

| ### Кхмерская Ходынка Выжившие в давке: “Женщины и дети умирали” Наталья Степанова ФотоВидео 6 |  | ### Олег Кашин перенес последнюю операцию Операцию, ставшую заключительным этапом хирургического лечения, сделали во вторник избитому журналисту Олегу Кашину 5
| ### Украинский футболист Владислав Пискун пытался повеситься Его спасли сотрудники милиции, за ним ведется наблюдение. 25 |  | ### К хищению из Пенсионного фонда присоединился бывший зампрефекта Громкое дело о хищении средств из Пенсионного фонда России получило свое продолжение 3

## Фото

25
А-студио "расстраивается"
8
Как Медведев будет бороться с проблемами ЖКХ
13
Давка в Камбодже унесла жизни 350 человек
10
Северная Корея обстреляла южнокорейский остров

## Экономика

### Клиенты “Капитала” спасаются из отелей по веревкам

Вчера на заседании экспертного совета по туризму при думском Комитете по экономической политике обсуждали ситуацию вокруг компании “Капитал-Тур”.

Марина Озерова, Татьяна Замахина 5

| ### За “коммуналку” будем платить “по-умному” Медведев пообещал спасти граждан от переплаты Татьяна Замахина Фото 5 |  | ### Чиновники подняли черту бедности Величина прожиточного минимума на III квартал текущего года установлена во вторник на заседании правительства Московской области Фото 3
| ### Налоговый Майдан Украинские предприниматели не хотят ни перед кем отчитываться Олег Базак |  | ### Россия останется без волос Наши женщины отдают на продажу свои пряди Ольга Тягнибеда 15

## МК в России

### Памяти Учителя…

### Историку Михаилу Супруну предъявят обвинение

### Ничего не помню!!!

### Культурно-архитектурный нигилизм

## Общество

### ФСБ защищается от террористов страшилками

Сотрудники УФСБ по Волгоградской области решили воспитать бдительность юного поколения. Они выпустили серию антитеррористических мультфильмов, рассчитанных на школьников и дошколят, причем в создании проекта не участвовали профессиональные аниматоры. 30-секундные ролики призывают к сознательности и бдительности подрастающее поколение и охватывают разные виды терроризма - от настоящего до телефонного. Ролики сопровождаются назидательными стихами. Критиков проекта оказалось много, с долей скептицизма отнеслись к творчеству сотрудников ФСБ и российские блогеры.

Видео

| ### Ну, “заяц”, проходи! Московские власти планируют убрать из наземного общественного транспорта турникеты Ольга Грекова, Татьяна Кирсанова 12 |  | ### Татьяна Догилева: “Не могла представить, что Михалков затеет такое” Актриса объяснила “МК” свою позицию в конфликте в Козихинском переулке Никита Карцев Фото 13
| ### Управы снесли все ларьки, кроме “своих” Владельцы торговых точек рассказали о беспределе Мария Егорова 7 |  | ### Кремль в рекламе не нуждается Из центра Москвы уберут всю “наружку”, мешающую им любоваться Елена Егорова 1

## Издания

### Алиса Гребенщикова: «Я стараюсь себе ничего не обещать, чтобы потом не разочаровываться»

### Дворец для духа

### Тайные династии

### Бегущий по волнам

## Культура

### Продается автограф Леннона своему убийце

Виниловая пластинка Джона Леннона "Double Fantasy", которую он подписал для Марка Дэвида Чэпмена за несколько часов до того, как он застрелил музыканта, выставили на продажу. Владелец альбома, чье имя не называется, оценил его в 850 тысяч долларов.

Фото

| ### В новом альбоме за Майкла Джексона спел пародист Не утихает скандал вокруг выхода пластинки "Michael" |  | ### Яйца Чайки. Часть 7 115 лет назад Чехов закончил пьесу Александр Минкин 7
| ### Ди Каприо до Питера довели Леонардо Ди Каприо, несмотря на все превратности судьбы, все-таки долетел до Петербурга Наталья Черных, Ольга Тягнибеда 3 |  | ### “Мэрилин Монро — странная птица в вольере” Выходят мемуары драматурга Артура Миллера Вера Копылова

## Партнеры

## Наука

### Родинка на лице обещает долгую жизнь без морщин

Наличие на лице родинок, возможно, не такое уж и плохое дело, как считалось до сих пор. По мнению британских исследователей, обладатели родинки на лице генетически отличаются от всех остальных.

Дмитрий Алексеев Фото

| ### Ученые воскресят древнейшую ДНК за 400 тысяч долларов Университетские исследователи из Бингемтона (США) извлекли древнюю бактерию, попавшую в многотысячелетнюю ловушку внутри капелек воды, втесненных в солевые кристаллы. Дмитрий Алексеев Фото |  | ### Есть ли мост на Марсе? Искусственный спутник обнаружил на Красной планете необычное сооружение Наталья Веденеева Фото 4
| ### Спецназ во времени. ВИДЕО “МК” отправляется на поиски древней суперцивилизации Александр Розензафт Фото 9 |  | ### Космонавты попробуют моря и океаны на соль Изучать последствия чересчур засушливого лета из космоса станут начиная с нового года российские специалисты

## Партнеры

SMI2

## Авто

### Интернет показал, в каких местах постоянно образуются пробки

Разговоры о пробках в последнее время уже даже поднадоели. Кажется, единственное, что москвичам остается, — это соревноваться, на чьем пути или в чьем районе они длиннее и продолжительнее.

Олег Адамович Фото 2

| ### Анатомия дорожной жизни В Электростали помянули погибших в ДТП Юлия Гончарова Фото 1 |  | ### Водители будут стоять в пробках по-умному Москва может взять на вооружение рязанский опыт управления движением Олег Адамович Фото 1
| ### В Москве не парковаться В мэрии нашли самый эффективный метод борьбы с пробками — превратить почти весь город в платную парковку Елена Егорова 33 |  | ### Изменения в ПДД должны снизить количество ДТП Светить, пристегиваться, пропускать Ольга Маранди Фото 17

## Спорт

### Кто осилит дорогу до Сочи?

Танцоры Екатерина Боброва и Дмитрий Соловьев, Елена Ильиных и Никита Кацалапов и, конечно, действующие чемпионы Европы в парном катании Юко Кавагути — Александр Смирнов могут смело занести домашний этап Гран-при себе в зачет.

Ирина Степанцева Фото

| ### Благословение “божьей руки” Диего Марадона посетил итоговый турнир АТР-2010 в Лондоне в компании знаменитого снукериста Ронни О'Салливана Елена Шпиз |  | ### Матч НБА окончился трагедией Кто виновен в гибели двухлетнего мальчика? Кирилл Степунин Фото
| ### Женщины с мужским оттенком В африканском спорте разгорается новый гендерный скандал Кирилл Степунин |  | ### Для “Спартака” пробил Марсельский час Смогут ли подопечные Валерия Карпина выйти в плей-офф Лиги чемпионов? Юрий Бутнев Фото

## Карикатуры А.Меринова

## Сегодня смотрят

1:27
Ракеты КНДР рвутся на улицах Южной Кореи

## обсуждения

| Как улучшить работу школ и детсадов?

## актуальное

| Жителям Кущевской затыкают рты

| Юрий Соломонов: Никита Михалков на фоне Льва Толстого

| Леонид Млечин: Истинные правители России

## самые читаемые

- Сегодня
- За неделю
- За месяц

24589

### Жители Кущевской — главе СКП: “При краевых властях и ментах вам ничего не расскажут”

Станица не открылась гостям из столицы

12049

### Следователи Кущевской взялись за старое

Убийство на Кубани обрастает новыми делами

8277

### “Сколково” — трубопровод для утечки мозгов

Через инноград наладят поставку на Запад русских ученых вместе с их открытиями

Весь рейтинг

155961

### Жителям Кущевской затыкают рты

Встреча с губернатором Ткачевым оказалась фарсом. Местная милиция “прессует” желающих дать показания против банды

78244

### “Это приговор местной милиции!”

Кущевскую обсудили в Думе

25936

### Задержаны еще два подозреваемых в убийстве на Кубани

Весь рейтинг

155964

### Жителям Кущевской затыкают рты

Встреча с губернатором Ткачевым оказалась фарсом. Местная милиция “прессует” желающих дать показания против банды

96497

### Главаря кущевской мафии сдали свои

Сергей Цапок был арестован по наводке ростовских бандитов

78244

### “Это приговор местной милиции!”

Кущевскую обсудили в Думе

Весь рейтинг

## самые комментируемые

- Сегодня
- За неделю
- За месяц

84

### Артиллерия КНДР обстреляла южнокорейский остров

Армия Южной Кореи приведена в полную боевую готовность

53

### “Сколково” — трубопровод для утечки мозгов

Через инноград наладят поставку на Запад русских ученых вместе с их открытиями

53

### Жители Кущевской — главе СКП: “При краевых властях и ментах вам ничего не расскажут”

Станица не открылась гостям из столицы

Весь рейтинг

213

### Жителям Кущевской затыкают рты

Встреча с губернатором Ткачевым оказалась фарсом. Местная милиция “прессует” желающих дать показания против банды

202

### Никита Михалков на фоне Льва Толстого

Чем консерватор лучше консерванта

138

### Олимпийский Мишико

Как Грузия собирается срывать Сочинскую олимпиаду?

Весь рейтинг

434

### Организация объединенных наци

«Русский марш-2010» впервые объединил все ультраправые движения Москвы

264

### Мычание Михалкова

Или Программа Божественной партии

225

### "Сталь" закалялась по заповедям Геббельса

Один из проектов движения "Наши" живет по заповедям канцлера Третьего рейха

Весь рейтинг

## опрос

##### По-вашему, конфликт между Северной и Южной Кореей закончится:

Укажите вариант ответа

| локальным вооруженным столкновением
| крупномасштабным вооруженным столкновением
| мирными переговорами
| вмешательством США

Все опросы

## онлайн — конференция

##### В гостях у «МК» - художественный руководитель «Театриума на Серпуховке» Тереза Дурова

25 ноября, в четверг, с 15.00 до 16.00 в гостях у «МК» художественный руководитель «Театриума на Серпуховке» Тереза Дурова. Свои вопросы Вы можете задать на сайте прямо сейчас. »

## пресс — конференция

##### 24 ноября пройдет вручение ежегодной Театральной премии

24 ноября в 14.00, в "МК" пройдет вручение 15-й, юбилейной ежегодной Театральной премии "Московского комсомольца". К нам, на церемонию вручения придут все звезды отечественного театра.

## Прошедшие конференции

##### В гостях у «МК» побывала балерина Анастасия Волочкова

17 ноября, в среду в пресс-центре «МК» прошла встреча с Заслуженной артисткой России, балериной Анастасией Волочковой. Ответы на вопросы знаменитой балерине Вы можете прочесть уже сейчас.

##### Как бороться с осенней депрессией?

11 ноября в «МК» состоялась прямая телефонная линия с руководителем Центра медико-психологической помощи при ЧС, зам. директора Государственного научного центра социальной и судебной психиатрии имени Сербского, доктора медицинских наук, профессора Зурабом Ильичом Кекелидзе. Читайте ответы эксперта в комментариях к этой публикации.

## 24 ноября в истории

Таинственное исчезновение в небе угонщика самолёта. Трагедия семьи Берберовых. Таинственная смерть Фредди Меркьюри.

В это день родились:

Александр Суворов (1730)

Армен Григорян (1960)

Бранко Радивоевич (1980)

Все события

| ###### Александр Минкин ### Яйца Чайки. Часть 7 ### Яйца Чайки. Часть 6 ### Яйца Чайки. Часть 5

| ###### Ольга Богуславская ### Поставьте диагноз судмедэкспертизе ### Тайный Алтай ### Скрытие покажет

| ###### Юлия Калинина ### “Дай лапу” достигла звериной зрелости ### Милиция в Кущевской раскрыла, что должна была не допустить ### Торбеев действовал бойко

| ###### Вадим Речкалов ### “Дай лапу” достигла звериной зрелости ### Три обезьяны Хусейна ### Война с мертвецами

| ###### Михаил Ростовский ### КНДР отстреливается из тупика ### Героин и Россия: кто кого? ### В чем логика Володина

| ###### Марина Перевозкина ### Олимпийский Мишико ### Запад готов “простить” Кремль за август-2008 ### Псевдоним “русский”

| ###### Александр Хинштейн ### Омское время на часах МВД ### Фальшивый доцент ### Спецоперация вранья

| ###### Ирина Боброва ### Неизвестная жертва “Боинга”, упавшего в Перми ### Майор изменил своим органам ### “Это твой сосед Олег, помоги!”

| ###### Ольга Божьева ### В армии все как-то некультурно ### Минобороны распродаст дома офицеров ### Челябинские толчки дошли до Кремля

## конкурсы

| День Победы

## гороскоп

- Гороскоп на сегодня
- Персональный гороскоп
- Персональный гороскоп на год
- Китайский гороскоп на год
- Гороскоп совместимости
- Финансовый гороскоп
- Любовный гороскоп
- Кармический гороскоп
- Детский гороскоп

## анекдоты

— Есть чиновники, которые не продаются? — Есть. Но их можно заказать.

Вся горячая пятёрка анекдотов

## Партнеры